]> Shamusworld >> Repos - rln/commitdiff
Update to the name (don't ask), and copyright dates. Now at v.1.7.0.
authorShamus Hammons <jlhamm@acm.org>
Sun, 7 Mar 2021 22:50:58 +0000 (16:50 -0600)
committerShamus Hammons <jlhamm@acm.org>
Sun, 7 Mar 2021 22:50:58 +0000 (16:50 -0600)
makefile
rln.c
rln.h

index b70cc77a8388f68cbcfd0729a71eda4bfd4c38e4..0c14fe63e5c9a5cbaa04aae4b7f22bae45f81476 100644 (file)
--- a/makefile
+++ b/makefile
@@ -1,5 +1,5 @@
 #
-# Makefile for Reboot's Linker for Jaguar
+# Makefile for Renamed Linker for Jaguar
 #
 RM =/bin/rm -f
 CC = gcc
@@ -21,18 +21,18 @@ endif
 endif
 
 CFLAGS = -g -I. -D$(SYSTYPE) -O2 -Wno-format
-SRCS = rln.c 
+SRCS = rln.c
 OBJS = rln.o
 
-.c.o: 
-       $(RM) $@ 
-       $(CROSS)$(CC) $(CFLAGS) -c $*.c 
+.c.o:
+       $(RM) $@
+       $(CROSS)$(CC) $(CFLAGS) -c $*.c
 
-all: $(PROGNAME) 
+all: $(PROGNAME)
 
-$(PROGNAME) : $(OBJS) 
-       $(CROSS)$(CC) $(CFLAGS) -o $(PROGNAME) $(OBJS) $(LIBS) 
+$(PROGNAME) : $(OBJS)
+       $(CROSS)$(CC) $(CFLAGS) -o $(PROGNAME) $(OBJS) $(LIBS)
 
-clean: 
-       $(RM) $(OBJS) $(PROGNAME) $(PROGNAME).exe *~ 
+clean:
+       $(RM) $(OBJS) $(PROGNAME) $(PROGNAME).exe *~
 
diff --git a/rln.h b/rln.h
index 75d6bb3f033c93fcf93da3801a22f1a2aac53176..5b45bed9712056894b5a28e21a4b65e98d9bbe42 100644 (file)
--- a/rln.h
+++ b/rln.h
@@ -1,6 +1,6 @@
 //
-// RLN - Reboot's Linker for the Atari Jaguar console system
-// Copyright (C) 199x Allan K. Pratt, 2011-2018 Reboot & Friends
+// RLN - Renamed Linker for the Atari Jaguar console system
+// Copyright (C) 199x Allan K. Pratt, 2011-2021 Reboot & Friends
 //
 
 #ifndef __RLN_H__
@@ -43,8 +43,8 @@
 #endif
 
 #define MAJOR   1                      // Major version number
-#define MINOR   6                      // Minor version number
-#define PATCH   4                      // Patch release number
+#define MINOR   7                      // Minor version number
+#define PATCH   0                      // Patch release number
 
 #ifdef WIN32
 #define PLATFORM     "Win32"           // Release platform - Windows
diff --git a/rln.c b/rln.c
index a0b5ab02aa040e7e4c071822b100bba2956addba..e451f4518e0916c2027d9611d994453eb1fbe10e 100644 (file)
--- a/rln.c
+++ b/rln.c
@@ -1,6 +1,6 @@
 //
// RLN - Reboot's Linker for the Atari Jaguar console system
// Copyright (C) 199x, Allan K. Pratt, 2014-2018 Reboot & Friends
 //
 
 #include "rln.h"
@@ -3050,8 +3050,8 @@ void ShowVersion(void)
                "| '__| | '_  \\\n"
                "| |  | | | | |\n"
                "|_|  |_|_| |_|\n"
-               "\nReboot's Linker for Atari Jaguar\n"
-               "Copyright (c) 199x Allan K. Pratt, 2014-2018 Reboot\n"
+               "\nRenamed Linker for Atari Jaguar\n"
+               "Copyright (c) 199x Allan K. Pratt, 2014-2021 Reboot & Friends\n"
                "V%i.%i.%i %s (%s)\n\n", MAJOR, MINOR, PATCH, __DATE__, PLATFORM);
        }
 }
@@ -1,6 +1,6 @@
 //
-// RLN - Reboot's Linker for the Atari Jaguar console system
-// Copyright (C) 199x, Allan K. Pratt, 2014-2018 Reboot & Friends
+// RLN - Renamed Linker for the Atari Jaguar console system
+// Copyright (C) 199x, Allan K. Pratt, 2014-2021 Reboot & Friends
 //
 